FL.objects.TTH.TTH
==================

.. currentmodule:: FL.objects.TTH

.. autoclass:: TTH
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TTH.BuildFromLinks
      ~TTH.Init
      ~TTH.Initoutline
      ~TTH.LoadFromTextFile
      ~TTH.LoadProgram
      ~TTH.ResetAllDeltas
      ~TTH.ResetFinalDeltas
      ~TTH.ResetProgram
      ~TTH.RunCommand
      ~TTH.RunProgram
      ~TTH.SaveProgram
      ~TTH.SaveToTextFile
      ~TTH.SetPPM
      ~TTH.SortProgram
      ~TTH.TestProgram
      ~TTH.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TTH.base_bottom_zones
      ~TTH.base_hstems
      ~TTH.base_outline
      ~TTH.base_top_zones
      ~TTH.base_vstems
      ~TTH.bottom_zones
      ~TTH.commands
      ~TTH.font
      ~TTH.glyph
      ~TTH.hstems
      ~TTH.outline
      ~TTH.ppm
      ~TTH.problems
      ~TTH.top_zones
      ~TTH.upm
      ~TTH.vstems
      ~TTH.zero_point
   
   